##  FACT_SHEET_FIELD_UPDATED

```
{
  "id": 42860,
  "path": "/externalId",
  "type": "FactSheetFieldUpdatedEvent",
  "fsType": "Application",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "newValue": {
    "type": "ExternalId",
    "status": "ACTIVE",
    "comment": null,
    "externalId": "123456",
    "externalUrl": null
  },
  "oldValue": {
    "type": "ExternalId",
    "status": "ACTIVE",
    "comment": null,
    "externalId": "123456789",
    "externalUrl": null
  },
  "createdAt": "2024-02-16T13:23:03.697933Z",
  "fsIdAndRev": {
    "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "rev": 7
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "transactionSequenceNumber": 75093
}
```



